@@ -460,8 +460,7 @@ int Device::output(int iOutputId)
 	if (poCalculator)
 		return poCalculator->getResult();
 
-	QString s = "Device::output: no such output id" + QString::number(iOutputId);
-	warning(s);
+	warning("Device::output: no such output id");
 	return 0;
 }
 
