@@ -272,7 +272,7 @@ void DlgEqu::done(int r)
 			collectEquations();
 
 			// create the equation device
-			dev = net->newDevice(DeviceType::fEQU, 20, 20);
+			dev = net->newDevice(DeviceType::fEQU, QPoint(20, 20));
 
 			if (NetWidget::getSimMode() == NetWidget::MODE_SIM_MULT)
 				NetWidget::simTimer.stop();
@@ -280,11 +280,11 @@ void DlgEqu::done(int r)
 			// create all outputs and set the equations
 			lout = equations->First();
 			while(lout) {
-				if (lout->Get()->output_type == Device::INTERNAL_OUTPUT) {
+				if (lout->Get()->output_type == Global::Device::INTERNAL_OUTPUT) {
 					io_id = dev->addInternalName(lout->Get()->output_name);
 					dev->Device::setEquation(lout->Get()->equation, io_id);
 				}
-				if (lout->Get()->output_type == Device::FINAL_OUTPUT) {
+				if (lout->Get()->output_type == Global::Device::FINAL_OUTPUT) {
 					dev->setSize(dev->neededSize() + 1);
 					io_id = dev->addOutputName(lout->Get()->output_name);
 					dev->Device::setEquation(lout->Get()->equation, io_id);
@@ -428,9 +428,9 @@ void DlgEqu::editEquation(int idx)
 
 		// display new edit box label
 		sprintf(cbuf, "%s", (const char *)ls->Get()->output_name);
-		if (ls->Get()->output_type == Device::INTERNAL_OUTPUT) {
+		if (ls->Get()->output_type == Global::Device::INTERNAL_OUTPUT) {
 			rbInternal->setChecked(TRUE);
-		} else if (ls->Get()->output_type == Device::FINAL_OUTPUT) {
+		} else if (ls->Get()->output_type == Global::Device::FINAL_OUTPUT) {
 			rbFinal->setChecked(TRUE);
 		} else {
 			rbTemp->setChecked(TRUE);
@@ -445,7 +445,7 @@ void DlgEqu::editEquation(int idx)
 // equation editing finished (change button pressed)
 void DlgEqu::editEquationOK()
 {	const char *newTypeName;
-	int newType;
+	Global::Device::IOTYPE newType;
 	char old_edit_slot;
 
 	if (edit_key) {
@@ -455,13 +455,13 @@ void DlgEqu::editEquationOK()
 			// set new output type
 			if (rbInternal->isChecked()) {
 				newTypeName = TYPE_INTERN;
-				newType = Device::INTERNAL_OUTPUT;
+				newType = Global::Device::INTERNAL_OUTPUT;
 			} else if (rbFinal->isChecked()) {
 				newTypeName = TYPE_FINAL;
-				newType = Device::FINAL_OUTPUT;
+				newType = Global::Device::FINAL_OUTPUT;
 			} else {
 				newTypeName = TYPE_NONE;
-				newType = Device::TMP_OUTPUT;
+				newType = Global::Device::TMP_OUTPUT;
 			}
 
 			// change output name
@@ -655,11 +655,11 @@ void DlgEqu::newEquation()
 
 		// set output type
 		if (rbInternal->isChecked()) {
-			oi->output_type = Device::INTERNAL_OUTPUT;
+			oi->output_type = Global::Device::INTERNAL_OUTPUT;
 		} else if (rbFinal->isChecked()) {
-			oi->output_type = Device::FINAL_OUTPUT;
+			oi->output_type = Global::Device::FINAL_OUTPUT;
 		} else {
-			oi->output_type = Device::TMP_OUTPUT;
+			oi->output_type = Global::Device::TMP_OUTPUT;
 		}
 
 		// append the new "output<-equation" to the list
@@ -755,7 +755,7 @@ void DlgEqu::collectEquations()
 {	KlogicList<OutputInfo> *ls1 = equations->First();
 
 	while(ls1) {
-		if (ls1->Get()->output_type != Device::INTERNAL_OUTPUT && ls1->Get()->output_type != Device::FINAL_OUTPUT) {
+		if (ls1->Get()->output_type != Global::Device::INTERNAL_OUTPUT && ls1->Get()->output_type != Global::Device::FINAL_OUTPUT) {
 			OutputInfo *oi = ls1->Get();
 			ls1->Destroy(oi);
 			delete oi;
@@ -779,7 +779,7 @@ int DlgEqu::substituteEquations()
 	QString dummy;					// dummy entry for substituted - list
 	int changed;					// circuit equations changed
 	int iplane;
-	int plane = Device::TMP_OUTPUT;
+	int plane = Global::Device::TMP_OUTPUT;
 
 	// security question
 	if (equations->counter() > 50) {
@@ -790,9 +790,9 @@ int DlgEqu::substituteEquations()
 
 	changed = 0;
 	for (iplane = 0; iplane < 3; iplane++) {
-		if (iplane == 0) plane = Device::TMP_OUTPUT;
-		if (iplane == 2) plane = Device::INTERNAL_OUTPUT;
-		if (iplane == 1) plane = Device::FINAL_OUTPUT;
+		if (iplane == 0) plane = Global::Device::TMP_OUTPUT;
+		if (iplane == 2) plane = Global::Device::INTERNAL_OUTPUT;
+		if (iplane == 1) plane = Global::Device::FINAL_OUTPUT;
 		ls1 = equations->First();
 		while(ls1) {
 			if (plane == ls1->Get()->output_type) {
@@ -819,19 +819,19 @@ int DlgEqu::substituteEquations()
 						if (NULL != (ls2 = equations->With(oCalcRules.getItem(i)))) {
 							int iOutputType = 0;
 							// already marked as internal output?
-							if (ls2->Get()->output_type == Device::INTERNAL_OUTPUT) {
-								iOutputType = Device::INTERNAL_OUTPUT;
+							if (ls2->Get()->output_type == Global::Device::INTERNAL_OUTPUT) {
+								iOutputType = Global::Device::INTERNAL_OUTPUT;
 							}
 
 							// ls1 and ls2 are the same equation?
 							// already subsituted? there is a loop, mark as internal output
-							if (iOutputType != Device::INTERNAL_OUTPUT && (ls1 == ls2 || substituted.With(oCalcRules.getItem(i)))) {
-								ls2->Get()->output_type = Device::INTERNAL_OUTPUT;
-								iOutputType = Device::INTERNAL_OUTPUT;
+							if (iOutputType != Global::Device::INTERNAL_OUTPUT && (ls1 == ls2 || substituted.With(oCalcRules.getItem(i)))) {
+								ls2->Get()->output_type = Global::Device::INTERNAL_OUTPUT;
+								iOutputType = Global::Device::INTERNAL_OUTPUT;
 							}
 
 							// substitute..
-							if (iOutputType != Device::INTERNAL_OUTPUT) {
+							if (iOutputType != Global::Device::INTERNAL_OUTPUT) {
 								QString s = ls1->Get()->equation.left(oCalcRules[i].m_iPos);
 								s += "(";
 								s += ls2->Get()->equation;
@@ -891,8 +891,8 @@ void DlgEqu::fillList()
 	QString s;
 	while(ls) {
 		s = ls->Get()->output_name;
-		if (ls->Get()->output_type == Device::INTERNAL_OUTPUT) s += TYPE_INTERN;
-		else if (ls->Get()->output_type == Device::FINAL_OUTPUT) s += TYPE_FINAL;
+		if (ls->Get()->output_type == Global::Device::INTERNAL_OUTPUT) s += TYPE_INTERN;
+		else if (ls->Get()->output_type == Global::Device::FINAL_OUTPUT) s += TYPE_FINAL;
 		s += " = ";
 		s += ls->Get()->equation;
 		if (s.length() > 4096) {
