@@ -13,8 +13,8 @@ class Grid
 		Grid();
 
 		//-- grid alignment
-		static QPoint getAligned(QPoint);
-		static QRect getAligned(QRect);
+		static QPoint getAligned(const QPoint&);
+		static QRect getAligned(const QRect&);
 
 		//-- paints background and grid for entire virtual screen
 		static	void 	draw( QPainter* );
