@@ -48,11 +48,11 @@ private slots:
 private:
 	XDevice *dev;
 
-	QCheckBox *iswitch[XDevice::MAXSIZE];
-	KlogicList<XWire> iwire[XDevice::MAXSIZE];
+	QCheckBox *iswitch[Global::Device::MAXSIZE];
+	KlogicList<XWire> iwire[Global::Device::MAXSIZE];
 	QButtonGroup *bg_i;
-	QCheckBox *oswitch[XDevice::MAXSIZE];
-	KlogicList<XWire> owire[XDevice::MAXSIZE];
+	QCheckBox *oswitch[Global::Device::MAXSIZE];
+	KlogicList<XWire> owire[Global::Device::MAXSIZE];
 	QButtonGroup *bg_o;
 };
 
