@@ -32,11 +32,10 @@ public:
 	bool write(bool, bool, int, int);
 	bool writeXML(bool, bool, int, int);
 	bool writeXML(QTextStream&, bool, bool, int, int);
-	bool writeNet(bool, bool, int, int);
-	bool writeNet(QTextStream&, bool, bool, int, int);
-
 	bool readXML();
 	bool readXML(QTextStream&, bool, int, int);
+
+	// old format
 	bool readNet(bool);
 	bool readNet(bool, QTextStream *, int, Circuit *_net = (Circuit *)NULL, int dx = 0, int dy = 0);
 
