@@ -116,10 +116,10 @@ private:
 	void selRightMenu(QMouseEvent *);
 	void selRightSelMenu(QMouseEvent *);
 
-	Circuit *activeNet;
-	XDevice *activeDev;
-	XWire *activeWire;
-	Selection *activeSelection;
+	Circuit *m_poActiveCircuit;
+	XDevice *m_poActiveDevice;
+	XWire *m_poActiveWire;
+	Selection *m_poActiveSelection;
 
 	QPopupMenu *rpop;
 	QPopupMenu *rselpop;
