@@ -54,7 +54,6 @@ private:
 
     QButtonGroup *bg_clock;
     QRadioButton *clock[7];
-    QCheckBox *invert_trigger;
 
     QGroupBox *gb_sim;
     QLabel *lstepTime;
@@ -70,7 +69,7 @@ private:
     QPushButton *bCancel;
     QPushButton *bOK;
 
-    int curr_clk;
+    Global::Device::CLOCKTYPE curr_clk;
     int curr_undef;
     int curr_invert;
 };
