@@ -128,7 +128,7 @@ private:
 	// position to paste at
 	QPoint paste_at;
 
-	Circuit *net;
+	Circuit *m_poCircuit;
 };
 
 #endif
