@@ -296,25 +296,28 @@ void SimW::graphChange()
 	for(int i=0; i < slotcnt; i++)
 		memcpy(slot[i], fill0, 1024);
 
-	KlogicList<XDevice> *netdev;
-	netdev = net->devPointer()->First();
 	slotcnt = 0;
 	ldev.Destroy();
-	while(netdev) {
-		XDevice *dev = netdev->Get();
+	DeviceList::iterator iter = net->getDeviceIterator();
+	DeviceList::iterator endIter = net->getDeviceEndIterator();
+	while(iter != endIter) {
+		XDevice *dev = iter.getDevice();
 		QString sName = dev->getName();
+
 		if (dev->drawGraph() && dev->graphEnabled()) {
 			if (dev->hasNamedOutput()) {
-				KlogicList<Calculator> *named_output = dev->getNamedORef()->First();
-				named_output = named_output->Next();
-				while(named_output) {
-					if (!named_output->Get()->isInternal()) {
+				ConnectorList::iterator iter2 = dev->getNamedOutputIterator();
+				iter2++;
+				while (iter2 != dev->getNamedOutputEndIterator()) {
+					Connector& oConnector = *iter2;
+					Calculator *poCalculator = *oConnector;
+					if (!poCalculator->isInternal()) {
 						// estimate the needed text space
 						// better would be a QPainter::boundingRect function here ..
 						sName.append(" (");
-						sName.append(named_output->getText());
+						sName.append(oConnector.getName());
 						sName.append(")");
-						ldev.Append(dev, dev->getID(), named_output->getID1())->setText(sName);
+						ldev.Append(dev, dev->getID(), oConnector.getConnectorID())->setText(sName);
 						if ((int)sName.length() * 7 > MINX) MINX = sName.length() * 7;
 						slotcnt++;
 						// prevent slot overflow
@@ -329,7 +332,7 @@ void SimW::graphChange()
 							return;
 						}
 					}
-					named_output = named_output->Next();
+					iter2++;
 				}
 			} else {
 				ldev.Append(dev, dev->getID())->setText(sName);
@@ -348,7 +351,7 @@ void SimW::graphChange()
 				}
 			}
 		}
-		netdev = netdev->Next();
+		iter++;
 	}
 
 	if (c1x < MINX) c1x = MINX;
