@@ -35,14 +35,14 @@ Wire::Wire()
 	o_ins_node2.setX(0);
 	o_ins_node2.setY(0);
 	bMustErase = 0;
-	color = Qt::black;
-	input[0] = (QPoint *)NULL;
-	input[1] = (QPoint *)NULL;
-	output[0] = (QPoint *)NULL;
-	output[1] = (QPoint *)NULL;
-	io_point[0] = (QPoint *)NULL;
-	io_point[1] = (QPoint *)NULL;
-	size = 1;
+	m_oColor = Qt::black;
+	m_poInputNode[0] = (QPoint *)NULL;
+	m_poInputNode[1] = (QPoint *)NULL;
+	m_poOutputNode[0] = (QPoint *)NULL;
+	m_poOutputNode[1] = (QPoint *)NULL;
+	m_poWireNode[0] = (QPoint *)NULL;
+	m_poWireNode[1] = (QPoint *)NULL;
+	m_iSize = 1;
 }
 
 Wire::Wire(QPoint src)
@@ -62,14 +62,14 @@ Wire::Wire(QPoint src)
 	o_ins_node2.setX(0);
 	o_ins_node2.setY(0);
 	bMustErase = 0;
-	color = Qt::black;
-	input[0] = (QPoint *)NULL;
-	input[1] = (QPoint *)NULL;
-	output[0] = (QPoint *)NULL;
-	output[1] = (QPoint *)NULL;
-	io_point[0] = (QPoint *)NULL;
-	io_point[1] = (QPoint *)NULL;
-	size = 1;
+	m_oColor = Qt::black;
+	m_poInputNode[0] = (QPoint *)NULL;
+	m_poInputNode[1] = (QPoint *)NULL;
+	m_poOutputNode[0] = (QPoint *)NULL;
+	m_poOutputNode[1] = (QPoint *)NULL;
+	m_poWireNode[0] = (QPoint *)NULL;
+	m_poWireNode[1] = (QPoint *)NULL;
+	m_iSize = 1;
 }
 
 Wire::~Wire()
@@ -82,7 +82,7 @@ Wire::~Wire()
                 l = l->Next();
 	}
 	wire.Destroy();
-	io_point_foreign.Destroy();
+	m_oForeignWireNodes.Destroy();
 	selnode.Destroy();
 }
 
@@ -98,9 +98,9 @@ KlogicList<QPoint> *Wire::contains(QPoint p)
 	// if point is in a node, lock node 
 	while(l) {
 		if (*(l->Get()) == p) {
-			if (l->Get() == io_point[0] || l->Get() == io_point[1] ||
-			    l->Get() == output[0] || l->Get() == output[1] ||
-			    l->Get() == input[0] || l->Get() == input[1])
+			if (l->Get() == m_poWireNode[0] || l->Get() == m_poWireNode[1] ||
+			    l->Get() == m_poOutputNode[0] || l->Get() == m_poOutputNode[1] ||
+			    l->Get() == m_poInputNode[0] || l->Get() == m_poInputNode[1])
 				// looks connected, try others!
 				retList = l;
 			else {
@@ -212,12 +212,12 @@ int Wire::getMaxSelY()
 
 // set size of the wire line
 // only set by XWire
-void Wire::setLineSize(int new_size)
+void Wire::setLineSize(int iSize)
 {
-	if (size != new_size) {
-		old_size = size;
+	if (m_iSize != iSize) {
+		m_iOldSize = m_iSize;
 		enforceCompleteDrawing();
-		size = new_size;
+		m_iSize = iSize;
 	}
 }
 
@@ -236,18 +236,17 @@ int Wire::lockSelectedNode()
 }
 
 // move all selected nodes
-void Wire::addPos(int dx, int dy)
+void Wire::moveBy(const QPoint& oDelta)
 {	KlogicList<QPoint> *l = selnode.First();
 	QPoint *pt;
 
 	while(l) {
 		pt = l->Get();
 		// do not move nodes connected to a device
-		if (pt != input[0] && pt != input[1] && pt != output[0] && pt != output[1]) {
+		if (pt != m_poInputNode[0] && pt != m_poInputNode[1] && pt != m_poOutputNode[0] && pt != m_poOutputNode[1]) {
 			// do not move nodes wich are references
-			if (pt != io_point[0] && pt != io_point[1]) {
-				pt->setX(pt->x() + dx);
-				pt->setY(pt->y() + dy);
+			if (pt != m_poWireNode[0] && pt != m_poWireNode[1]) {
+				*pt += oDelta;
 			}
 		}
 		l = l->Next();
@@ -266,7 +265,7 @@ int Wire::createNode(const QPoint& p)
 
 		// new node, if no successor and not connected, otherwise existing node
 		if (l->Prev() && !l->Next()) {
-			if ((pt != input[0]) && (pt != input[1]) && (pt != output[0]) && (pt != output[1]) && (pt != io_point[0]) && (pt != io_point[1])) {
+			if ((pt != m_poInputNode[0]) && (pt != m_poInputNode[1]) && (pt != m_poOutputNode[0]) && (pt != m_poOutputNode[1]) && (pt != m_poWireNode[0]) && (pt != m_poWireNode[1])) {
 				current_node = new QPoint(*pt);
 				return lockNode(wire.Append(current_node));
 			}
@@ -274,7 +273,7 @@ int Wire::createNode(const QPoint& p)
 
 		// new node, if no successor and not connected, otherwise existing node
 		if (!l->Prev() && l->Next()) {
-			if ((pt != input[0]) && (pt != input[1]) && (pt != output[0]) && (pt != output[1]) && (pt != io_point[0]) && (pt != io_point[1])) {
+			if ((pt != m_poInputNode[0]) && (pt != m_poInputNode[1]) && (pt != m_poOutputNode[0]) && (pt != m_poOutputNode[1]) && (pt != m_poWireNode[0]) && (pt != m_poWireNode[1])) {
 				current_node = new QPoint(*pt);
 				return lockNode(wire.Insert(current_node, 0, pt));
 			}
@@ -300,10 +299,10 @@ int Wire::lockNode(QPoint pt)
 	KlogicList<QPoint> *l = wire.Last();
 	QPoint *lp = l->Get();
 
-	if (*fp == pt && io_point[0] != fp && io_point[1] != fp)
+	if (*fp == pt && m_poWireNode[0] != fp && m_poWireNode[1] != fp)
 		return lockNode(f);
 
-	if (*lp == pt && io_point[0] != lp && io_point[1] != lp)
+	if (*lp == pt && m_poWireNode[0] != lp && m_poWireNode[1] != lp)
 		return lockNode(l);
 
 	return NODE_NOLOCK;
@@ -366,10 +365,10 @@ bool Wire::lockLastNode()
 void Wire::cutNode()
 {	if (current_node) {
 		wire.Destroy(current_node);
-		io_point_foreign.Destroy(current_node);
+		m_oForeignWireNodes.Destroy(current_node);
 		selnode.Destroy(current_node);
-		if (io_point[0] == current_node) io_point[0] = (QPoint *)NULL;
-		if (io_point[1] == current_node) io_point[1] = (QPoint *)NULL;
+		if (m_poWireNode[0] == current_node) m_poWireNode[0] = (QPoint *)NULL;
+		if (m_poWireNode[1] == current_node) m_poWireNode[1] = (QPoint *)NULL;
 		current_node = (QPoint *)NULL;
 	}
 }
@@ -380,10 +379,10 @@ void Wire::removeNode()
 {
 	if (current_node) {
 		wire.Destroy(current_node);
-		io_point_foreign.Destroy(current_node);
+		m_oForeignWireNodes.Destroy(current_node);
 		selnode.Destroy(current_node);
-		if (io_point[0] == current_node) io_point[0] = (QPoint *)NULL;
-		if (io_point[1] == current_node) io_point[1] = (QPoint *)NULL;
+		if (m_poWireNode[0] == current_node) m_poWireNode[0] = (QPoint *)NULL;
+		if (m_poWireNode[1] == current_node) m_poWireNode[1] = (QPoint *)NULL;
 		if (from_node == current_node)
 			from_node = (QPoint *)NULL;
 		if (to_node == current_node)
@@ -421,12 +420,12 @@ QPoint *Wire::checkConnection(QPoint *pt)
 	// first of all, check if point lies near a point of this wire
 	if (NULL != (l1 = contains(*pt))) {
 		// never connect input- or output nodes!
-		if ((current_node == input[0]) || (current_node == input[1]) || (current_node == output[0]) || (current_node == output[1]))
+		if ((current_node == m_poInputNode[0]) || (current_node == m_poInputNode[1]) || (current_node == m_poOutputNode[0]) || (current_node == m_poOutputNode[1]))
 			return (QPoint *)NULL;
 
 		// insert foreign node into wire, append pt before the existing own node
 		wire.Insert(pt, 0, l1->Get());
-		io_point_foreign.Append(pt);
+		m_oForeignWireNodes.Append(pt);
 		// remove the existing (currently locked) node!
 		if (!activeIsReference() && !activeIsForeign()) {
 			removeNode();
@@ -452,7 +451,7 @@ QPoint *Wire::checkConnection(QPoint *pt)
 
 				// insert foreign node, append pt between the existing two own nodes
 				wire.Insert(pt, 0, l2->Get());
-				io_point_foreign.Append(pt);
+				m_oForeignWireNodes.Append(pt);
 				lockNode(pt);
 				return current_node;
 			}
@@ -524,8 +523,8 @@ QPoint *Wire::getActiveNode()
 // returns index of active node (wire-connection; conn1 or conn2)
 int Wire::getActiveConnIndex()
 {	if (!current_node) return WFAIL;
-	if (current_node == io_point[0]) return 0;
-	if (current_node == io_point[1]) return 1;
+	if (current_node == m_poWireNode[0]) return 0;
+	if (current_node == m_poWireNode[1]) return 1;
 	return WFAIL;
 }
 
@@ -533,8 +532,8 @@ int Wire::getActiveConnIndex()
 int Wire::activeIsInput()
 {
 	if (!current_node) return WFAIL;
-	if (current_node == input[0]) return 0;
-	if (current_node == input[1]) return 1;
+	if (current_node == m_poInputNode[0]) return 0;
+	if (current_node == m_poInputNode[1]) return 1;
 	return WFAIL;
 }
 
@@ -542,8 +541,8 @@ int Wire::activeIsInput()
 int Wire::nodeIsInput(QPoint *pt)
 {
 	if (!pt) return WFAIL;
-	if (pt == input[0]) return 0;
-	if (pt == input[1]) return 1;
+	if (pt == m_poInputNode[0]) return 0;
+	if (pt == m_poInputNode[1]) return 1;
 	return WFAIL;
 }
 
@@ -551,8 +550,8 @@ int Wire::nodeIsInput(QPoint *pt)
 int Wire::activeIsOutput()
 {
 	if (!current_node) return WFAIL;
-	if (current_node == output[0]) return 0;
-	if (current_node == output[1]) return 1;
+	if (current_node == m_poOutputNode[0]) return 0;
+	if (current_node == m_poOutputNode[1]) return 1;
 	return WFAIL;
 }
 
@@ -560,8 +559,8 @@ int Wire::activeIsOutput()
 int Wire::nodeIsOutput(QPoint *pt)
 {
 	if (!pt) return WFAIL;
-	if (pt == output[0]) return 0;
-	if (pt == output[1]) return 1;
+	if (pt == m_poOutputNode[0]) return 0;
+	if (pt == m_poOutputNode[1]) return 1;
 	return WFAIL;
 }
 
@@ -576,7 +575,7 @@ bool Wire::activeIsEnd()
 // returns 1, if active node is reference of a connection
 bool Wire::activeIsReference()
 {
-	if ((current_node == io_point[0]) || (current_node == io_point[1])) return true;
+	if ((current_node == m_poWireNode[0]) || (current_node == m_poWireNode[1])) return true;
 	return false;
 }
 
@@ -584,14 +583,14 @@ bool Wire::activeIsReference()
 //            which another wire posesses
 bool Wire::activeIsForeign()
 {
-	if (io_point_foreign.With(current_node)) return true;
+	if (m_oForeignWireNodes.With(current_node)) return true;
 	return false;
 }
 
 // returns 1 if point is reference of a connection (first or last node)
 // this wire posesses the node
 bool Wire::nodeIsReference(QPoint *pt)
-{	if ((pt == io_point[0]) || (pt == io_point[1])) {
+{	if ((pt == m_poWireNode[0]) || (pt == m_poWireNode[1])) {
 		// lock the point
 		current_node = pt;
 		o_node = *current_node;
@@ -604,7 +603,7 @@ bool Wire::nodeIsReference(QPoint *pt)
 // another wire posesses the node
 bool Wire::nodeIsForeign(QPoint *pt)
 {
-	if (io_point_foreign.With(pt)) return true;
+	if (m_oForeignWireNodes.With(pt)) return true;
 	return false;
 }
 
@@ -622,57 +621,100 @@ void Wire::enforceCompleteDrawing()
 // draw wire after erasing active parts
 void Wire::drawImage(QPainter *p)
 {	KlogicList<QPoint> *l = wire.First();
-	int f = 0;
-	QColor &_color = color;
+	bool bColorSet = false;
+	QColor &oColor = m_oColor;
 
 	if (bMustErase)
 		eraseWire(p);
 
+	p->setPen(QPen(oColor, m_iSize));
 	while(l && l->Get() && l->Next() && l->Next()->Get()) {
 		// draw selected nodes green
 		if (selnode.With(l->Get()) || selnode.With(l->Next()->Get())) {
-			if (!f) {
-				f = 1;
-				_color = Qt::green;
+			if (!bColorSet) {
+				bColorSet = true;
+				oColor = Qt::green;
 			}
+		} else if (bColorSet) {
+			bColorSet = false;
 		}
-		else if (f) {
-			f = 0;
-		}
-		p->setPen(QPen(_color, size));
 		p->drawLine(*(l->Get()), *(l->Next()->Get()));
 		l = l->Next();
 	}
-	if (io_point[0]) drawSolderedPoint(p, Qt::black, *io_point[0]);
-	if (io_point[1]) drawSolderedPoint(p, Qt::black, *io_point[1]);
+	if (m_poWireNode[0])
+		drawSolderedPoint(p, Qt::black, *m_poWireNode[0]);
+	if (m_poWireNode[1])
+		drawSolderedPoint(p, Qt::black, *m_poWireNode[1]);
+
+	drawConnections(p, BOTH);
+}
+
+void Wire::drawConnections(QPainter *p, IO_TYPE iType, int idx)
+{
+	if (iType == INPUT) {
+		if (m_poInputNode[idx]) {
+			//cout << "drawConnections INPUT" << endl;
+			QPoint oEndP(*(m_poInputNode[idx]) + QPoint(4,0));
+			//if (p->pen().color() == Qt::white)
+				//cout << "color is white" << endl;
+			p->drawLine(*(m_poInputNode[idx]), oEndP);
+			if (inputIsInverted(idx)) {
+				QPoint oInvP(*(m_poInputNode[idx]) + QPoint(3,0));
+				drawInverterPoint(p, Qt::black, oInvP);
+			}
+		}
+		return;
+	}
+	if (iType == OUTPUT) {
+		if (m_poOutputNode[idx]) {
+			//cout << "drawConnections OUTPUT" << endl;
+			QPoint oEndP(*(m_poOutputNode[idx]) + QPoint(-4,0));
+			p->drawLine(*(m_poOutputNode[idx]), oEndP);
+			if (outputIsInverted(idx)) {
+				QPoint oInvP(*(m_poOutputNode[idx]) + QPoint(-1,0));
+				drawInverterPoint(p, Qt::black, oInvP);
+			}
+		}
+		return;
+	}
+	if (iType == BOTH) {
+		drawConnections(p, INPUT, 0);
+		drawConnections(p, INPUT, 1);
+		drawConnections(p, OUTPUT, 0);
+		drawConnections(p, OUTPUT, 1);
+		return;
+	}
 }
 
 // erase whole wire
 void Wire::eraseWire(QPainter *p)
-{	KlogicList<QPoint> *l = wire.First();
-	QPoint *p1, *p2;
+{
+	if (m_poWireNode[0]) drawSolderedPoint(p, Qt::white, *m_poWireNode[0]);
+	if (m_poWireNode[1]) drawSolderedPoint(p, Qt::white, *m_poWireNode[1]);
 
-	if (io_point[0]) drawSolderedPoint(p, Qt::white, *io_point[0]);
-	if (io_point[1]) drawSolderedPoint(p, Qt::white, *io_point[1]);
+	KlogicList<QPoint> *l = wire.First();
 	while(l && l->Next()) {
-		p1 = l->Get();
-		p2 = l->Next()->Get();
+		QPoint *p1 = l->Get();
+		QPoint *p2 = l->Next()->Get();
 		if (bMustErase)
-			p->setPen(QPen(Qt::white, old_size));
+			p->setPen(QPen(Qt::white, m_iOldSize));
 		else
-			p->setPen(QPen(Qt::white, size));
+			p->setPen(QPen(Qt::white, m_iSize));
 		p->drawLine(*p1, *p2);
 
 		restoreArry(p, p1->x(), p1->y(), p2->x(), p2->y());
 		l = l->Next();
 	}
-	old_size = 0;
+	drawConnections(p, BOTH);
+
+	m_iOldSize = 0;
 	bMustErase = false;
 }
 
 // erase first, active, and last part of wire
 void Wire::erase(QPainter *p)
-{	QPoint pt2;
+{
+	QPoint pt2;
 	KlogicList<QPoint> *first = wire.First();
 	QPoint *firstp = (QPoint *)NULL;
 	if (first) firstp = first->Get();
@@ -686,9 +728,9 @@ void Wire::erase(QPainter *p)
 	if (o_end_node.isNull()) o_end_node = *lastp;
 
 	// node inserted: erase old part of wire
+	p->setPen(QPen(Qt::white, m_iSize));
 	if (!o_ins_node1.isNull() && !o_ins_node2.isNull()) {
 		// delete old wire-part and restore grid
-		p->setPen(QPen(Qt::white, size));
 		p->drawLine(o_ins_node1, o_ins_node2);
 		restoreArry(p, o_ins_node1.x(), o_ins_node1.y(), o_ins_node2.x(), o_ins_node2.y());
 		o_ins_node1.setX(0);
@@ -701,17 +743,15 @@ void Wire::erase(QPainter *p)
 	if (o_node.x() != -1 && o_node.y() != -1) {
 		// delete old wire-part and restore grid
 		if (from_node) {
-			p->setPen(QPen(Qt::white, size));
 			p->drawLine(*from_node, o_node);
 			restoreArry(p, from_node->x(), from_node->y(), o_node.x(), o_node.y());
 		}
 		if (to_node) {
-			p->setPen(QPen(Qt::white, size));
 			p->drawLine(o_node, *to_node);
 			restoreArry(p, to_node->x(), to_node->y(), o_node.x(), o_node.y());
 		}
 		// remove connection-point
-		if (current_node && ((current_node == io_point[0]) || (current_node == io_point[1])))
+		if (current_node && ((current_node == m_poWireNode[0]) || (current_node == m_poWireNode[1])))
 			drawSolderedPoint(p, Qt::white, o_node);
 		o_node.setX(-1);
 		o_node.setY(-1);
@@ -721,7 +761,7 @@ void Wire::erase(QPainter *p)
 	// firstp: new position of first node of wire
 	if (o_start_node != *firstp) {
 		// remove connection-point
-		if ((firstp == io_point[0]) || (firstp == io_point[1]))
+		if ((firstp == m_poWireNode[0]) || (firstp == m_poWireNode[1]))
 			drawSolderedPoint(p, Qt::white, o_start_node);
 		// erase first part of wire if changed
 		// value of old start-node (first node) is in o_start_node
@@ -729,20 +769,29 @@ void Wire::erase(QPainter *p)
 			pt2 = *first->Next()->Get();
 			// erase old wire-part
 			if (!o_start_node.isNull()) {
-				p->setPen(QPen(Qt::white, size));
 				p->drawLine(o_start_node, pt2);
 			}
 			// restore grid
 			restoreArry(p, o_start_node.x(), o_start_node.y(), pt2.x(), pt2.y());
 		}
 		o_start_node = *firstp;
+		//cout << "-->>moving first node" << endl;
+		drawConnections(p, BOTH);
 	}
 
 	// o_end_node: old position of last point of wire
 	// lastp: new position of last node of wire
 	if (o_end_node != *lastp) {
+		//cout << "moving last node" << endl;
+		for (int idx = 0; idx < 2; idx++) {
+			if (m_poOutputNode[idx] == lastp)
+				drawConnections(p, OUTPUT, idx);
+			if (m_poInputNode[idx] == lastp)
+				drawConnections(p, INPUT, idx);
+		}
+		//drawConnections(p, BOTH);
 		// remove connection-point
-		if ((lastp == io_point[0]) || (lastp == io_point[1]))
+		if ((lastp == m_poWireNode[0]) || (lastp == m_poWireNode[1]))
 			drawSolderedPoint(p, Qt::white, o_end_node);
 		// erase last part of wire if changed
 		// value of last end-node (last node) is in o_end_node
@@ -750,13 +799,13 @@ void Wire::erase(QPainter *p)
 			pt2 =*last->Prev()->Get();
 			// erase old wire-part
 			if (!o_end_node.isNull()) {
-				p->setPen(QPen(Qt::white, size));
 				p->drawLine(o_end_node, pt2);
 			}
 			// restore grid
 			restoreArry(p, o_end_node.x(), o_end_node.y(), pt2.x(), pt2.y());
 		}
 		o_end_node = *lastp;
+		drawConnections(p, BOTH);
 	}
 }
 
@@ -764,26 +813,52 @@ void Wire::erase(QPainter *p)
 void Wire::draw(QPainter *p)
 {
 	if (current_node) {
-		p->setPen(QPen(color, size));
+		p->setPen(QPen(m_oColor, m_iSize));
 		if (from_node) p->drawLine(*from_node, *current_node);
 		if (to_node) p->drawLine(*current_node, *to_node);
+		if (current_node == m_poWireNode[0] || current_node == m_poWireNode[1])
+			drawSolderedPoint(p, Qt::black, o_node);
 	}
 }
 
 // draw connection between wires
-void Wire::drawSolderedPoint(QPainter *p, QColor _color, QPoint pt)
-{	if (bMustErase)
-		p->setPen(QPen(_color, old_size));
-	else
-		p->setPen(QPen(_color, size));
-	p->setBrush(_color);
+void Wire::drawSolderedPoint(QPainter *p, QColor oColor, QPoint pt)
+{
+	bool bChangeCol = false;
+	QColor oOldColor = p->pen().color();
+	if (oOldColor != oColor) {
+		bChangeCol = true;
+		p->setPen(oColor);
+		if (bMustErase)
+			p->setPen(QPen(oColor, m_iOldSize));
+		else
+			p->setPen(QPen(oColor, m_iSize));
+		p->setBrush(oColor);
+	}
 	p->drawPie(pt.x() - 2, pt.y() - 2, 4, 4, 0, 5760);
+	if (bChangeCol)
+		p->setPen(oColor);
+}
+
+// draw connection between wires
+void Wire::drawInverterPoint(QPainter *p, QColor oColor, QPoint pt)
+{	if (bMustErase)
+		p->setPen(QPen(oColor, m_iOldSize));
+	else
+		p->setPen(QPen(oColor, m_iSize));
+	p->setBrush(oColor);
+	p->drawPie(pt.x() - 3, pt.y() - 3, 6, 6, 0, 5760);
 }
 
 void Wire::restoreArry(QPainter *p, int x1, int y1, int x2, int y2)
 {	int i, j, a, b, c, d;
+	bool bChangeCol = false;
 
-	p->setPen(Qt::black);
+	QColor oColor = p->pen().color();
+	if (oColor != Qt::black) {
+		bChangeCol = true;
+		p->setPen(Qt::black);
+	}
 	if (x1 < x2) {
 		a = x1;
 		b = x2;
@@ -805,6 +880,8 @@ void Wire::restoreArry(QPainter *p, int x1, int y1, int x2, int y2)
 			p->drawPoint(i,j);
 		}
 	}
+	if (bChangeCol)
+		p->setPen(oColor);
 }
 
 void Wire::updateNode(QPoint p)
@@ -824,7 +901,7 @@ QPoint *Wire::align(QPoint *p)
 
 void Wire::setColor(QColor c)
 {
-	color = c;
+	m_oColor = c;
 }
 
 // remove useless nodes
@@ -892,10 +969,10 @@ void Wire::garbageCollection()
 int Wire::connectInput(int idx)
 {
 	if(current_node && (!to_node || !from_node)) {
-		if (input[idx])
+		if (m_poInputNode[idx])
 			return WFAIL;
 
-		input[idx] = current_node;
+		m_poInputNode[idx] = current_node;
 		return idx;
 	}
 	fatal(NOACTIVECONN);
@@ -905,17 +982,17 @@ int Wire::connectInput(int idx)
 // reset input-node
 void Wire::disconnectInput(int idx)
 {
-	input[idx] = (QPoint *)NULL;
+	m_poInputNode[idx] = (QPoint *)NULL;
 }
 
 // set the active node as output-node, if it's an endpoint
 int Wire::connectOutput(int idx)
 {
 	if(current_node && (!to_node || !from_node)) {
-		if (output[idx])
+		if (m_poOutputNode[idx])
 			return WFAIL;
 
-		output[idx] = current_node;
+		m_poOutputNode[idx] = current_node;
 		return idx;
 	}
 	fatal(NOACTIVECONN);
@@ -925,17 +1002,17 @@ int Wire::connectOutput(int idx)
 // reset output-node
 void Wire::disconnectOutput(int idx)
 {
-	output[idx] = (QPoint *)NULL;
+	m_poOutputNode[idx] = (QPoint *)NULL;
 }
 
 // set io-point for connection to another wire
 int Wire::connectWire(int idx)
 {
 	if (current_node) {
-		if (io_point[idx])
+		if (m_poWireNode[idx])
 			return WFAIL;
 
-		io_point[idx] = current_node;
+		m_poWireNode[idx] = current_node;
 		return idx;
 	}
 	return WFAIL;
@@ -943,21 +1020,21 @@ int Wire::connectWire(int idx)
 
 void Wire::disconnectWire(int idx)
 {
-	io_point[idx] = (QPoint *)NULL;
+	m_poWireNode[idx] = (QPoint *)NULL;
 }
 
 // change position of input-node (device-connection nodes) on the currently locked node
 void Wire::setInputPosition(QPoint newp)
 {
 	if (!current_node) fatal("Wire::setInputPosition: no current node!?");
-	if (current_node == input[0]) *(input[0]) = newp;
-	else if (current_node == input[1]) *(input[1]) = newp;
+	if (current_node == m_poInputNode[0]) *(m_poInputNode[0]) = newp;
+	else if (current_node == m_poInputNode[1]) *(m_poInputNode[1]) = newp;
 }
 
 // change position of input-node (device-connection nodes)
 void Wire::setInputPosition(QPoint newp, int idx)
 {
-	if (input[idx]) *(input[idx]) = newp;
+	if (m_poInputNode[idx]) *(m_poInputNode[idx]) = newp;
 	else fatal("Wire::setInputPosition: no connection point in >%d<", idx);
 }
 
@@ -965,14 +1042,14 @@ void Wire::setInputPosition(QPoint newp, int idx)
 void Wire::setOutputPosition(QPoint newp)
 {
 	if (!current_node) fatal("Wire::setOutputPosition: no current node!?");
-	if (current_node == output[0]) *(output[0]) = newp;
-	else if (current_node == output[1]) *(output[1]) = newp;
+	if (current_node == m_poOutputNode[0]) *(m_poOutputNode[0]) = newp;
+	else if (current_node == m_poOutputNode[1]) *(m_poOutputNode[1]) = newp;
 }
 
 // change position of output-node (device-connection nodes)
 void Wire::setOutputPosition(QPoint newp, int idx)
 {
-	if (output[idx]) *(output[idx]) = newp;
+	if (m_poOutputNode[idx]) *(m_poOutputNode[idx]) = newp;
 	else fatal("Wire::setOutputPosition: no connection point in >%d<", idx);
 }
 
@@ -980,9 +1057,9 @@ void Wire::setOutputPosition(QPoint newp, int idx)
 QPoint Wire::getInputPosition(int idx, int selonly)
 {
 	QPoint p(0,0);
-	if (input[idx]) {
-		if (!selonly) return *(input[idx]);
-		if (selnode.With(input[idx])) return *(input[idx]);
+	if (m_poInputNode[idx]) {
+		if (!selonly) return *(m_poInputNode[idx]);
+		if (selnode.With(m_poInputNode[idx])) return *(m_poInputNode[idx]);
 	}
 	return p;
 }
@@ -990,9 +1067,9 @@ QPoint Wire::getInputPosition(int idx, int selonly)
 // get position of input-node (device-connection nodes)
 QPoint Wire::getOutputPosition(int idx, int selonly)
 {
-	if (output[idx]) {
-		if (!selonly) return *(output[idx]);
-		if (selnode.With(output[idx])) return *(output[idx]);
+	if (m_poOutputNode[idx]) {
+		if (!selonly) return *(m_poOutputNode[idx]);
+		if (selnode.With(m_poOutputNode[idx])) return *(m_poOutputNode[idx]);
 	}
 
 	return QPoint(0,0);
@@ -1001,9 +1078,9 @@ QPoint Wire::getOutputPosition(int idx, int selonly)
 // get position of input/output-node (wire-connection nodes)
 QPoint Wire::getIOPosition(int idx, int selonly)
 {
-	if (io_point[idx]) {
-		if (!selonly) return *(io_point[idx]);
-		if (selnode.With(io_point[idx])) return *(io_point[idx]);
+	if (m_poWireNode[idx]) {
+		if (!selonly) return *(m_poWireNode[idx]);
+		if (selnode.With(m_poWireNode[idx])) return *(m_poWireNode[idx]);
 	}
 	return QPoint(0,0);
 }
