@@ -59,7 +59,7 @@ public:
 
 private:
 	virtual void createXML(bool selected);
-	Circuit *net;
+	Circuit *m_poCircuit;
 };
 
 /*******************************************/
