@@ -19,7 +19,7 @@
 #include "xmlSymbolMap.h"
 #include "version.h"
 
-const char * XmlField::XML_ROOT = "<!xml version=\"1.0\" ?>\n";
+const char * XmlField::XML_ROOT = "<?xml version=\"1.0\" ?>\n";
 
 // static
 QString& XmlField::unquote(QString& content)
@@ -29,14 +29,7 @@ QString& XmlField::unquote(QString& content)
 	content.replace(QRegExp("&gt;"), ">");
 	content.replace(QRegExp("&quot;"), "\"");
 	content.replace(QRegExp("&apos;"), "'");
-/*
-	content.replace(QRegExp("&auml;"), "");
-	content.replace(QRegExp("&ouml;"), "");
-	content.replace(QRegExp("&uuml;"), "");
-	content.replace(QRegExp("&Auml;"), "");
-	content.replace(QRegExp("&Ouml;"), "");
-	content.replace(QRegExp("&Uuml;"), "");
-*/
+
 	content.replace(QRegExp("&#167;"), "");
 	content.replace(QRegExp("&#228;"), "");
 	content.replace(QRegExp("&#246;"), "");
@@ -55,14 +48,7 @@ QString& XmlField::quote(QString& content)
 	content.replace(QRegExp(">"), "&gt;");
 	content.replace(QRegExp("\""), "&quot;");
 	content.replace(QRegExp("'"), "&apos;");
-/*
-	content.replace(QRegExp(""), "&auml;");
-	content.replace(QRegExp(""), "&ouml;");
-	content.replace(QRegExp(""), "&uuml;");
-	content.replace(QRegExp(""), "&Auml;");
-	content.replace(QRegExp(""), "&Ouml;");
-	content.replace(QRegExp(""), "&Uuml;");
-*/
+
 	content.replace(QRegExp(""), "&#228;");
 	content.replace(QRegExp(""), "&#246;");
 	content.replace(QRegExp(""), "&#252;");
