@@ -306,7 +306,7 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 			activeNet[activeNetIdx] = net;
 		} else {
 			// create sub circuits
-			activeDev = activeNet[activeNetIdx - 1]->newDevice(type, x, y, size);
+			activeDev = activeNet[activeNetIdx - 1]->newDevice(type, QPoint(x, y), size);
 			if (!activeDev) {
 				error_msg += i18n("unable to create circuit device\n");
 				error_cnt++;
@@ -363,7 +363,7 @@ bool XMLImportHandler::startElement(const QString&, const QString&, const QStrin
 			x += atts.value(3).toInt();
 			y += atts.value(4).toInt();
 		}
-		activeDev = activeNet[activeNetIdx]->newDevice(type, x, y, size);
+		activeDev = activeNet[activeNetIdx]->newDevice(type, QPoint(x, y), size);
 		if (!activeDev) {
 			error_msg += i18n("unable to create device (circuit depth ");
 			error_msg += QString::number(activeNetIdx);
@@ -737,17 +737,20 @@ bool XMLImportHandler::setDeviceTag(XDevice *dev, const QString& ch)
 	}
 
 	if (id == XmlSymbol::UNDEF) {
-		dev->setUndef(ch.toInt());
+		dev->setUndefinedValue(ch.toInt());
 		return true;
 	}
 
 	if (id == XmlSymbol::STAT) {
-		dev->setStaticInput(ch.toInt());
+		dev->setInputValue(ch.toInt());
 		return true;
 	}
 
 	if (id == XmlSymbol::CLK_TYPE) {
-		dev->setClock(ch.toInt());
+		int iClock = ch.toInt();
+		Global::Device::CLOCKTYPE tClock = (Global::Device::CLOCKTYPE)ch.toInt();
+		dev->setClock(tClock);
+		dev->setOscType(iClock);
 		return true;
 	}
 
@@ -804,6 +807,11 @@ bool XMLImportHandler::setDeviceTag(XDevice *dev, const QString& ch)
 		return true;
 	}
 
+	if (id == XmlSymbol::COLOR) {
+		dev->setColor(ch.toInt());
+		return true;
+	}
+
 	// equation device output
 	if (id == XmlSymbol::OUT_EQU) {
 		int dev_id;
@@ -888,8 +896,6 @@ bool XMLImportHandler::endElement(const QString&, const QString&, const QString&
 
 		activeDev->setImage();
 
-		activeDev->setTextDevPos();
-
 		activeDev->select(imp_selected);
 
 		activeDev = (XDevice *)NULL;
@@ -909,17 +915,15 @@ bool XMLImportHandler::endElement(const QString&, const QString&, const QString&
 
 		activeNet[activeNetIdx]->select(imp_selected);
 
-		// the image could have changed by io devices!
+		// image could have changed by io devices!
 		if (activeNet[activeNetIdx]->type() == DeviceType::fNET)
 			activeNet[activeNetIdx]->setImage();
 
-		// parse the equations
+		// parse equations
 		if (activeNet[activeNetIdx]->type() == DeviceType::fEQU)
 			activeNet[activeNetIdx]->parseEquation();
 
-		activeNet[activeNetIdx]->setTextDevPos();
-
-		// close the circuit
+		// close circuit
 		activeNetIdx--;
 		if (activeNetIdx < 0) {
 			error_msg += i18n("unexpected circuit close\n");
