@@ -6,6 +6,7 @@
 #include <qpixmap.h>
 #include <xdevice.h>
 #include <wire.h>
+#include <deviceFactory.h>
 
 /*********************************************
 * a connection between two devices
@@ -17,7 +18,7 @@ public:
 
 	XWire(QPoint);
 	XWire();
-	~XWire();
+	virtual ~XWire();
 
 	// get information about the wire
 	XDevice * outputDevice(int);
@@ -39,9 +40,7 @@ public:
 	// node methods
 	bool contains(QPoint);
 	int createNode(QPoint);
-	void updateNode(QPoint);
 	XWire * removeNode();
-	void releaseNode();
 
 	// set references in this and others, graphics and logical (device-connection)
 	int connectInput(XDevice *, int, int);
@@ -53,9 +52,11 @@ public:
 
 	// set/reset inverter
 	void invertInput(XDevice *, bool);
-	int inputIsInverted(XDevice *);
+	bool inputIsInverted(XDevice *);
+	virtual bool inputIsInverted(int);
 	void invertOutput(XDevice *, bool);
-	int outputIsInverted(XDevice *);
+	bool outputIsInverted(XDevice *);
+	virtual bool outputIsInverted(int);
 
 	// check for wire-connection (this = potential connected wire), update device-connections
 	int checkConnection(XWire *);
@@ -110,11 +111,11 @@ private:
 	// number of output devices
 	int checkShortcut();
 
-	// connected input devices
+	// connected input devices (at end of wire)
 	XDevice *in_dev[2];
 	int in_id[2];
 
-	// connected output devices
+	// connected output devices (at beginning of wire, input giving devices)
 	XDevice *out_dev[2];
 	int out_id[2];
 
@@ -131,6 +132,8 @@ private:
 
 	XDevice *out_inv[2];
 	int output_is_inv[2];
+
+	static DeviceFactory *m_poDeviceFactory;
 };
 
 #endif
